@@ -11,23 +11,23 @@
 #define DCMTK_UNSIGNED_LONG_DIGITS10 19
 #define DCMTK_FLOAT_MAX_DIGITS10 9
 #define DCMTK_DOUBLE_MAX_DIGITS10 17
-#define DCMTK_CHAR_TRAPS OFTrue
+#define DCMTK_CHAR_TRAPS OFFalse
 #define DCMTK_CHAR_MODULO OFTrue
-#define DCMTK_SIGNED_CHAR_TRAPS OFTrue
+#define DCMTK_SIGNED_CHAR_TRAPS OFFalse
 #define DCMTK_SIGNED_CHAR_MODULO OFTrue
-#define DCMTK_UNSIGNED_CHAR_TRAPS OFTrue
+#define DCMTK_UNSIGNED_CHAR_TRAPS OFFalse
 #define DCMTK_UNSIGNED_CHAR_MODULO OFTrue
-#define DCMTK_SIGNED_SHORT_TRAPS OFTrue
+#define DCMTK_SIGNED_SHORT_TRAPS OFFalse
 #define DCMTK_SIGNED_SHORT_MODULO OFTrue
-#define DCMTK_UNSIGNED_SHORT_TRAPS OFTrue
+#define DCMTK_UNSIGNED_SHORT_TRAPS OFFalse
 #define DCMTK_UNSIGNED_SHORT_MODULO OFTrue
-#define DCMTK_SIGNED_INT_TRAPS OFTrue
+#define DCMTK_SIGNED_INT_TRAPS OFFalse
 #define DCMTK_SIGNED_INT_MODULO OFTrue
-#define DCMTK_UNSIGNED_INT_TRAPS OFTrue
+#define DCMTK_UNSIGNED_INT_TRAPS OFFalse
 #define DCMTK_UNSIGNED_INT_MODULO OFTrue
-#define DCMTK_SIGNED_LONG_TRAPS OFTrue
+#define DCMTK_SIGNED_LONG_TRAPS OFFalse
 #define DCMTK_SIGNED_LONG_MODULO OFTrue
-#define DCMTK_UNSIGNED_LONG_TRAPS OFTrue
+#define DCMTK_UNSIGNED_LONG_TRAPS OFFalse
 #define DCMTK_UNSIGNED_LONG_MODULO OFTrue
 #define DCMTK_FLOAT_TRAPS OFFalse
 #define DCMTK_DOUBLE_TRAPS OFFalse
@@ -39,12 +39,12 @@
 #define DCMTK_FLOAT_QUIET_NAN *OFreinterpret_cast( const float*, "\000\000\300\177" )
 #define DCMTK_DOUBLE_HAS_QUIET_NAN OFTrue
 #define DCMTK_DOUBLE_QUIET_NAN *OFreinterpret_cast( const double*, "\000\000\000\000\000\000\370\177" )
-#define DCMTK_FLOAT_HAS_SIGNALING_NAN OFTrue
+#define DCMTK_FLOAT_HAS_SIGNALING_NAN OFFalse
 #define DCMTK_FLOAT_SIGNALING_NAN *OFreinterpret_cast( const float*, "\001\000\200\177" )
-#define DCMTK_DOUBLE_HAS_SIGNALING_NAN OFTrue
+#define DCMTK_DOUBLE_HAS_SIGNALING_NAN OFFalse
 #define DCMTK_DOUBLE_SIGNALING_NAN *OFreinterpret_cast( const double*, "\001\000\000\000\000\000\360\177" )
-#define DCMTK_FLOAT_IS_IEC559 OFTrue
-#define DCMTK_DOUBLE_IS_IEC559 OFTrue
+#define DCMTK_FLOAT_IS_IEC559 OFFalse
+#define DCMTK_DOUBLE_IS_IEC559 OFFalse
 #define DCMTK_FLOAT_HAS_DENORM OFdenorm_present
 #define DCMTK_FLOAT_DENORM_MIN *OFreinterpret_cast( const float*, "\001\000\000\000" )
 #define DCMTK_DOUBLE_HAS_DENORM OFdenorm_present
