@@ -35,7 +35,7 @@
 #endif
 
 /* Define the canonical host system type as a string constant */
-#define CANONICAL_HOST_TYPE "mips64-OpenBSD"
+#define CANONICAL_HOST_TYPE "riscv64-OpenBSD"
 
 /* Define if char is unsigned on the C compiler */
 /* #undef C_CHAR_UNSIGNED */
@@ -53,11 +53,15 @@
 /* Define the default data dictionary path for the dcmdata library package */
 #define DCM_DICT_DEFAULT_PATH "/usr/local/share/dcmtk/dicom.dic"
 
-/* Define if we want a populated builtin dictionary */
-/* #undef ENABLE_BUILTIN_DICTIONARY */
+/* Define the type of standard dictionary that we want to use:
+   0 - Do not load any default dictionary on startup
+   1 - Load builtin dictionary on startup
+   2 - Load external (i.e. file-based) dictionary on startup
+*/
+#define DCM_DICT_DEFAULT 2
 
-/* Define if we want load external dictionaries */
-#define ENABLE_EXTERNAL_DICTIONARY "1"
+/* Define whether dictionaries defined through DCMDICTPATH variable should be loaded */
+#define DCM_DICT_USE_DCMDICTPATH 1
 
 /* Define the environment variable path separator */
 #define ENVIRONMENT_PATH_SEPARATOR ':'
@@ -86,9 +90,6 @@
 /* Define to 1 if you have the `bind' function. */
 #define HAVE_BIND 1
 
-/* Define to 1 if you have the `bzero' function. */
-#define HAVE_BZERO 1
-
 /* Define if your C++ compiler can work with class templates */
 #define HAVE_CLASS_TEMPLATE 1
 
@@ -104,15 +105,15 @@
 /* Define to 1 if you have the `cuserid' function. */
 /* #undef HAVE_CUSERID */
 
-/* Define if bool is a built-in type */
-#define HAVE_CXX_BOOL 1
-
 /* Define if volatile is a known keyword */
 #define HAVE_CXX_VOLATILE 1
 
 /* Define if "const" is supported by the C compiler */
 #define HAVE_C_CONST 1
 
+/* Define if your system has a declaration for fp_except_t in ieeefp.h */
+/* #undef HAVE_DECLARATION_FP_EXCEPT_T */
+
 /* Define if your system has a declaration for socklen_t in sys/types.h
    sys/socket.h */
 #define HAVE_DECLARATION_SOCKLEN_T 1
@@ -225,12 +226,18 @@
 /* Define to 1 if you have the `getpwnam' function. */
 #define HAVE_GETPWNAM 1
 
+/* Define to 1 if you have the `getrusage' function. */
+#define HAVE_GETRUSAGE 1
+
 /* Define to 1 if you have the `getsockname' function. */
 #define HAVE_GETSOCKNAME 1
 
 /* Define to 1 if you have the `getsockopt' function. */
 #define HAVE_GETSOCKOPT 1
 
+/* Define to 1 if you have the `gettimeofday' function. */
+#define HAVE_GETTIMEOFDAY 1
+
 /* Define to 1 if you have the `getuid' function. */
 #define HAVE_GETUID 1
 
@@ -306,9 +313,6 @@
 /* Define to 1 if you have the `socket' library (-lsocket). */
 /* #undef HAVE_LIBSOCKET */
 
-/* Define if libtiff supports LZW compression */
-#define HAVE_LIBTIFF_LZW_COMPRESSION 1
-
 /* Define to 1 if you have the <limits.h> header file. */
 #define HAVE_LIMITS_H 1
 
@@ -393,6 +397,9 @@
 /* Define to 1 if you have the <sys/systeminfo.h> header file. */
 /* #undef HAVE_SYS_SYSTEMINFO_H */
 
+/* Define to 1 if you have the <iterator> header file. */
+#define HAVE_ITERATOR_HEADER 1
+
 /* Define to 1 if you have readdir_r */
 #define HAVE_READDIR_R 1
 
@@ -411,10 +418,6 @@
 /* Define if your system has a prototype for bind in sys/types.h sys/socket.h */
 #define HAVE_PROTOTYPE_BIND 1
 
-/* Define if your system has a prototype for bzero in string.h strings.h
-   libc.h unistd.h stdlib.h */
-#define HAVE_PROTOTYPE_BZERO 1
-
 /* Define if your system has a prototype for connect in sys/types.h
    sys/socket.h */
 #define HAVE_PROTOTYPE_CONNECT 1
@@ -422,6 +425,9 @@
 /* Define if your system has a prototype for finite in math.h */
 #define HAVE_PROTOTYPE_FINITE 1
 
+/* Define to 1 if your has a prototype for `TryAcquireSRWLockShared' in windows.h (Win32 only). */
+/* #undef HAVE_PROTOTYPE_TRYACQUIRESRWLOCKSHARED */
+
 /* Define if your system has a prototype for std::finite in cmath */
 /* #undef HAVE_PROTOTYPE_STD__FINITE */
 
@@ -461,16 +467,16 @@
 #define HAVE_PROTOTYPE_GETTIMEOFDAY 1
 
 /* Define if your system has a prototype for isinf in math.h */
-/* #undef HAVE_PROTOTYPE_ISINF */
+#define HAVE_PROTOTYPE_ISINF 1
 
 /* Define if your system has a prototype for isnan in math.h */
-/* #undef HAVE_PROTOTYPE_ISNAN */
+#define HAVE_PROTOTYPE_ISNAN 1
 
 /* Define if your system has a prototype for std::isinf in cmath */
-/* #undef HAVE_PROTOTYPE_STD__ISINF */
+#define HAVE_PROTOTYPE_STD__ISINF 1
 
 /* Define if your system has a prototype for std::isnan in cmath */
-/* #undef HAVE_PROTOTYPE_STD__ISNAN */
+#define HAVE_PROTOTYPE_STD__ISNAN 1
 
 /* Define if your system has a prototype for fpclassf in math.h */
 /* #undef HAVE_PROTOTYPE__FPCLASSF */
@@ -638,6 +644,9 @@
 /* Define to 1 if `strerror_r' returns a char*. */
 /* #undef HAVE_CHARP_STRERROR_R */
 
+/* Define to 1 if you have the <streambuf.h> header file. */
+/* #undef HAVE_STREAMBUF_H */
+
 /* Define to 1 if you have the <strings.h> header file. */
 #define HAVE_STRINGS_H 1
 
@@ -840,16 +849,16 @@
 /* #undef PACKAGE_TARNAME */
 
 /* Define to the date of this package. */
-#define PACKAGE_DATE "2018-02-05"
+#define PACKAGE_DATE "2022-04-22"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "3.6.3"
+#define PACKAGE_VERSION "3.6.7"
 
 /* Define to the version suffix of this package. */
 #define PACKAGE_VERSION_SUFFIX ""
 
 /* Define to the version number of this package. */
-#define PACKAGE_VERSION_NUMBER 363
+#define PACKAGE_VERSION_NUMBER 367
 
 /* Define path separator */
 #define PATH_SEPARATOR '/'
@@ -900,9 +909,6 @@
 /* Define to 1 if your <sys/time.h> declares `struct tm'. */
 /* #undef TM_IN_SYS_TIME */
 
-/* Define if ANSI standard C++ includes are used */
-#define USE_STD_CXX_INCLUDES
-
 /* Define if we are compiling with libiconv support. */
 #define WITH_LIBICONV
 
@@ -923,6 +929,12 @@
 /* Define if the second argument to iconv() is const */
 /* #undef LIBICONV_SECOND_ARGUMENT_CONST */
 
+/* Try to define the iconv behavior as conversion flags */
+#define DCMTK_FIXED_ICONV_CONVERSION_FLAGS AbortTranscodingOnIllegalSequence
+
+/* Define if iconv_open() accepts "" as an argument */
+/* #undef DCMTK_STDLIBC_ICONV_HAS_DEFAULT_ENCODING */
+
 /* Define if we are compiling with libpng support */
 #define WITH_LIBPNG
 
@@ -932,6 +944,9 @@
 /* Define if we are compiling with libxml support */
 #define WITH_LIBXML
 
+/* Define if we are compiling with OpenJPEG support */
+#define WITH_OPENJPEG
+
 /* Define if we are compiling with OpenSSL support */
 #define WITH_OPENSSL
 
@@ -1073,6 +1088,27 @@ typedef unsigned long ulong;
 /* Define if the compiler supports operator delete (std::nothrow) */
 #define HAVE_NOTHROW_DELETE 1
 
+/* Define if the compiler supports static_assert */
+#define HAVE_STATIC_ASSERT 1
+
+/* Define if the compiler supports [[deprecated]] */
+#define HAVE_CXX14_DEPRECATED_ATTRIBUTE 1
+
+/* Define if the compiler supports [[deprecated("message")]] */
+#define HAVE_CXX14_DEPRECATED_ATTRIBUTE_MSG 1
+
+/* Define if the compiler supports __attribute__((deprecated)) */
+#define HAVE_ATTRIBUTE_DEPRECATED 1
+
+/* Define if the compiler supports __attribute__((deprecated("message"))) */
+#define HAVE_ATTRIBUTE_DEPRECATED_MSG 1
+
+/* Define if the compiler supports __declspec(deprecated) */
+/* #undef HAVE_DECLSPEC_DEPRECATED */
+
+/* Define if the compiler supports __declspec(deprecated("message")) */
+/* #undef HAVE_DECLSPEC_DEPRECATED_MSG */
+
 /* Define if your system has a prototype for std::vfprintf in stdarg.h */
 #define HAVE_PROTOTYPE_STD__VFPRINTF 1
 
@@ -1091,12 +1127,6 @@ typedef unsigned long ulong;
 /* Define if your system provides sigjmp_buf as conditional jmp_buf alternative */
 #define HAVE_SIGJMP_BUF 1
 
-/* Define if your OpenSSL library provides the SSL_CTX_GET0_PARAM function */
-#define HAVE_SSL_CTX_GET0_PARAM 1
-
-/* Define if your OpenSSL library provides the RAND_egd function */
-/* #undef HAVE_RAND_EGD */
-
 /* Always define STDIO_NAMESPACE to ::, because MSVC6 gets mad if you don't. */
 #define STDIO_NAMESPACE ::
 
@@ -1108,6 +1138,22 @@ typedef unsigned long ulong;
 DCMTK was configured to use C++11 features, but your compiler does not or was not configured to provide them.
 #endif
 
+/* Define if we can use C++14 */
+/* #undef HAVE_CXX14 */
+
+#if defined(HAVE_CXX14) && defined(__cplusplus) && __cplusplus < 201402L
+#error\
+DCMTK was configured to use C++14 features, but your compiler does not or was not configured to provide them.
+#endif
+
+/* Define if we can use C++17 */
+/* #undef HAVE_CXX17 */
+
+#if defined(HAVE_CXX17) && defined(__cplusplus) && __cplusplus < 201703L
+#error\
+DCMTK was configured to use C++17 features, but your compiler does not or was not configured to provide them.
+#endif
+
 /* Define if the compiler supports __alignof__ */
 #define HAVE_GNU_ALIGNOF 1
 
@@ -1165,4 +1211,135 @@ DCMTK was configured to use C++11 features, but your compiler does not or was no
 /* Define if we are supposed to use STL's system_error */
 /* #undef HAVE_STL_SYSTEM_ERROR */
 
+/* Define if the input iterator category is supported */
+#define HAVE_INPUT_ITERATOR_CATEGORY 1
+
+/* Define if the input iterator category is supported */
+#define HAVE_OUTPUT_ITERATOR_CATEGORY 1
+
+/* Define if the input iterator category is supported */
+#define HAVE_FORWARD_ITERATOR_CATEGORY 1
+
+/* Define if the input iterator category is supported */
+#define HAVE_BIDIRECTIONAL_ITERATOR_CATEGORY 1
+
+/* Define if the input iterator category is supported */
+#define HAVE_RANDOM_ACCESS_ITERATOR_CATEGORY 1
+
+/* Define if the input iterator category is supported */
+/* #undef HAVE_CONTIGUOUS_ITERATOR_CATEGORY */
+
+/* Feature Tests for the OpenSSL Library */
+
+/* Define if your OpenSSL library provides the SSL_CTX_GET0_PARAM function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_GET0_PARAM 1
+
+/* Define if your OpenSSL library provides the RAND_egd function */
+/* #undef HAVE_OPENSSL_PROTOTYPE_RAND_EGD */
+
+/* Define if we have OpenSSL with the DH_bits() function */
+#define HAVE_OPENSSL_PROTOTYPE_DH_BITS 1
+
+/* Define if we have OpenSSL with the SSL_ERROR_WANT_ASYNC error code */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_ERROR_WANT_ASYNC 1
+
+/* Define if we have OpenSSL with the SSL_ERROR_WANT_ASYNC_JOB error code */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_ERROR_WANT_ASYNC_JOB 1
+
+/* Define if we have OpenSSL with the SSL_ERROR_WANT_CLIENT_HELLO_CB error code */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_ERROR_WANT_CLIENT_HELLO_CB 1
+
+/* Define if we have OpenSSL with the EVP_PKEY_base_id error code */
+#define HAVE_OPENSSL_PROTOTYPE_EVP_PKEY_BASE_ID 1
+
+/* Define if we have OpenSSL with the EVP_PKEY_RSA_PSS macro */
+#define HAVE_OPENSSL_PROTOTYPE_EVP_PKEY_RSA_PSS 1
+
+/* Define if we have OpenSSL with the SSL_CTX_get_cert_store() function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_GET_CERT_STORE 1
+
+/* Define if we have OpenSSL with the SSL_CTX_get_ciphers() function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_GET_CIPHERS 1
+
+/* Define if we have OpenSSL with the SSL_CTX_set0_tmp_dh_pkey() function */
+/* #undef HAVE_OPENSSL_PROTOTYPE_SSL_CTX_SET0_TMP_DH_PKEY */
+
+/* Define if we have OpenSSL with the SSL_CTX_set1_curves() function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_SET1_CURVES 1
+
+/* Define if we have OpenSSL with the SSL_CTX_set1_sigalgs() function */
+/* #undef HAVE_OPENSSL_PROTOTYPE_SSL_CTX_SET1_SIGALGS */
+
+/* Define if we have OpenSSL with the SSL_CTX_set_ecdh_auto() function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_SET_ECDH_AUTO 1
+
+/* Define if we have OpenSSL with the SSL_CTX_set_max_proto_version() function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_SET_MAX_PROTO_VERSION 1
+
+/* Define if we have OpenSSL with the SSL_CTX_set_security_level() function */
+#define HAVE_OPENSSL_PROTOTYPE_SSL_CTX_SET_SECURITY_LEVEL 1
+
+/* Define if we have OpenSSL with the TLS1_TXT_ECDHE_RSA_WITH_CHACHA20_POLY1305 macro */
+#define HAVE_OPENSSL_PROTOTYPE_TLS1_TXT_ECDHE_RSA_WITH_CHACHA20_POLY1305 1
+
+/* Define if we have OpenSSL with the TLS_method() function */
+#define HAVE_OPENSSL_PROTOTYPE_TLS_METHOD 1
+
+/* Define if we have OpenSSL with the X509_get_signature_nid() function */
+#define HAVE_OPENSSL_PROTOTYPE_X509_GET_SIGNATURE_NID 1
+
+/* Define if we have OpenSSL with the X509_STORE_get0_param() function */
+#define HAVE_OPENSSL_PROTOTYPE_X509_STORE_GET0_PARAM 1
+
+/* Define if we have OpenSSL with the ASN1_STRING_get0_data() function */
+#define HAVE_OPENSSL_PROTOTYPE_ASN1_STRING_GET0_DATA 1
+
+/* Define if we have OpenSSL with the new typedef of EVP_MD_CTX as struct evp_md_ctx_st */
+/* #undef HAVE_OPENSSL_DECLARATION_NEW_EVP_MD_CTX */
+
+/* Define if we have OpenSSL with the EVP_PKEY_get0_EC_KEY() function */
+#define HAVE_OPENSSL_PROTOTYPE_EVP_PKEY_GET0_EC_KEY 1
+
+/* Define if we have OpenSSL with the EVP_PKEY_get_group_name() function */
+/* #undef HAVE_OPENSSL_PROTOTYPE_EVP_PKEY_GET_GROUP_NAME */
+
+/* Define if we have OpenSSL with the EVP_PKEY_id() function */
+#define HAVE_OPENSSL_PROTOTYPE_EVP_PKEY_ID 1
+
+/* Define if we have OpenSSL with the OSSL_PROVIDER_load() function */
+/* #undef HAVE_OPENSSL_PROTOTYPE_OSSL_PROVIDER_LOAD */
+
+/* Define if we have the <openssl/provider.h> header file*/
+/* #undef HAVE_OPENSSL_PROVIDER_H */
+
+/* Define if we have OpenSSL with the TS_STATUS_INFO_get0_failure_info() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_STATUS_INFO_GET0_FAILURE_INFO 1
+
+/* Define if we have OpenSSL with the TS_STATUS_INFO_get0_status() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_STATUS_INFO_GET0_STATUS 1
+
+/* Define if we have OpenSSL with the TS_STATUS_INFO_get0_text() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_STATUS_INFO_GET0_TEXT 1
+
+/* Define if we have OpenSSL with the TS_VERIFY_CTS_set_certs() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_VERIFY_CTS_SET_CERTS 1
+
+/* Define if we have OpenSSL with the TS_VERIFY_CTX_set_data() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_VERIFY_CTX_SET_DATA 1
+
+/* Define if we have OpenSSL with the TS_VERIFY_CTX_set_flags() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_VERIFY_CTX_SET_FLAGS 1
+
+/* Define if we have OpenSSL with the TS_VERIFY_CTX_set_store() function */
+#define HAVE_OPENSSL_PROTOTYPE_TS_VERIFY_CTX_SET_STORE 1
+
+/* Define if we have OpenSSL with the X509_ALGOR_get0() function expecting a const pointer as first parameter */
+#define HAVE_OPENSSL_X509_ALGOR_GET0_CONST_PARAM 1
+
+/* Define if we have OpenSSL with the X509_get0_notAfter() function */
+#define HAVE_OPENSSL_PROTOTYPE_X509_GET0_NOTAFTER 1
+
+/* Define if we have OpenSSL with the X509_get0_notBefore() function */
+#define HAVE_OPENSSL_PROTOTYPE_X509_GET0_NOTBEFORE 1
+
 #endif /* !OSCONFIG_H*/
