@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2021, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -105,7 +105,7 @@ typedef enum {
     ERT_HangingProtocol = 35,
     /// stereometric relationships
     ERT_Stereometric = 36,
-    /// HL7 structured document
+    /// HL7 structured document (retired)
     ERT_HL7StrucDoc = 37,
     /// palette
     ERT_Palette = 38,
@@ -126,7 +126,11 @@ typedef enum {
     /// tractography
     ERT_Tract = 46,
     /// assessment
-    ERT_Assessment = 47
+    ERT_Assessment = 47,
+    /// radiotherapy
+    ERT_Radiotherapy = 48,
+    /// annotation
+    ERT_Annotation = 49
 } E_DirRecType;
 
 
@@ -143,7 +147,8 @@ public:
     /// default constructor
     DcmDirectoryRecord();
 
-    /** constructor
+    /** constructor.
+     *  Create new element from given tag and length.
      *  @param tag attribute tag
      *  @param len length of the attribute value
      */
@@ -286,7 +291,7 @@ public:
      *  @param pixelFileName not used
      *  @param pixelCounter not used
      */
-    virtual void print(STD_NAMESPACE ostream&out,
+    virtual void print(STD_NAMESPACE ostream &out,
                        const size_t flags = 0,
                        const int level = 0,
                        const char *pixelFileName = NULL,
@@ -305,7 +310,7 @@ public:
      *  @param maxReadLength Maximum read length for reading an attribute value.
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition read(DcmInputStream & inStream,
+    virtual OFCondition read(DcmInputStream &inStream,
                              const E_TransferSyntax xfer,
                              const E_GrpLenEncoding glenc = EGL_noChange,
                              const Uint32 maxReadLength = DCM_MaxReadLength);
@@ -315,7 +320,7 @@ public:
      *  @param flags optional flag used to customize the output (see DCMTypes::XF_xxx)
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition writeXML(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeXML(STD_NAMESPACE ostream &out,
                                  const size_t flags = 0);
 
 
@@ -461,7 +466,7 @@ protected:
 
     // side-effect-free conversion routines:
     E_DirRecType        recordNameToType(const char *recordTypeName);
-    char*               buildFileName(const char *origName, char *destName);
+    char*               buildFileName(const char *origName, char *destName, size_t len) const;
     OFCondition         checkHierarchy(const E_DirRecType upperRecord,
                                        const E_DirRecType lowerRecord);
 
