@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2020, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -119,7 +119,7 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
      *  @param pixelFileName optional filename used to write the raw pixel data file
      *  @param pixelCounter optional counter used for automatic pixel data filename creation
      */
-    virtual void print(STD_NAMESPACE ostream&out,
+    virtual void print(STD_NAMESPACE ostream &out,
                        const size_t flags = 0,
                        const int level = 0,
                        const char *pixelFileName = NULL,
@@ -128,11 +128,13 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
     /** make sure that all data elements of the file meta information header are existent
      *  in metainfo and contain correct values.
      *  @param oxfer the transfer syntax which shall be used
-     *  @param writeMode flag indicating whether to update the file meta information or not
+     *  @param writeMode flag indicating whether to update the file meta information or not.
+     *         The default behavior is to delete all old meta information in order to create
+     *         it from scratch.
      *  @return EC_Normal if valid, an error code otherwise
      */
     virtual OFCondition validateMetaInfo(const E_TransferSyntax oxfer,
-                                         const E_FileWriteMode writeMode = EWM_fileformat);
+                                         const E_FileWriteMode writeMode = EWM_createNewMeta);
 
     /** get file meta information header part of the fileformat
      *  @return reference to internally stored file meta information header
@@ -150,15 +152,7 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
      */
     DcmDataset *getAndRemoveDataset();
 
-    /** calculate the length of this DICOM element when encoded with the
-     *  given transfer syntax and the given encoding type for sequences.
-     *  For elements, the length includes the length of the tag, length field,
-     *  VR field and the value itself, for items and sequences it returns
-     *  the length of the complete item or sequence including delimitation tags
-     *  if applicable. Never returns undefined length.
-     *  @param xfer transfer syntax for length calculation
-     *  @param enctype sequence encoding type for length calculation
-     *  @return length of DICOM element
+    /** @copydoc DcmObject::calcElementLength()
      */
     virtual Uint32 calcElementLength(const E_TransferSyntax xfer,
                                      const E_EncodingType enctype);
@@ -229,6 +223,8 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
      *    DcmFileFormat to the DcmDataset object.
      *  @param writeMode write file with or without meta header. Also allows for
      *    updating the information in the file meta information header.
+     *    The default behavior is to delete all old meta information in order to
+     *    create it from scratch.
      *  @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition write(DcmOutputStream &outStream,
@@ -240,7 +236,7 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
                               const Uint32 padlen = 0,
                               const Uint32 subPadlen = 0,
                               Uint32 instanceLength = 0,
-                              const E_FileWriteMode writeMode = EWM_fileformat);
+                              const E_FileWriteMode writeMode = EWM_createNewMeta);
 
     /** write object in XML format.
      *  The XML declaration (e.g. <?xml version="1.0"?>) is not written by this function.
@@ -259,20 +255,6 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
     virtual OFCondition writeJson(STD_NAMESPACE ostream &out,
                                   DcmJsonFormat &format);
 
-    /** write object in JSON format.
-     *  @tparam Format the formatter class, e.g. DcmJsonFormatPretty.
-     *    Will be deduced automatically.
-     *  @param out output stream to which the JSON document is written
-     *  @param format used to format and customize the output
-     *  @return status, EC_Normal if successful, an error code otherwise
-     */
-    template<typename Format>
-    OFCondition writeJson(STD_NAMESPACE ostream &out,
-                          Format format)
-    {
-        return writeJson(out, OFstatic_cast(DcmJsonFormat&, format));
-    }
-
     /** load object from a DICOM file.
      *  This method supports DICOM objects stored as a file (with meta header) or as a
      *  dataset (without meta header).  By default, the presence of a meta header is
@@ -331,7 +313,9 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
      *  @param padLength number of bytes used for the dataset padding (has to be an even number)
      *  @param subPadLength number of bytes used for the item padding (has to be an even number)
      *  @param writeMode write file with or without meta header. Also allows for updating the
-     *    information in the file meta information header.
+     *    information in the file meta information header. The default behavior is to delete
+     *    all old meta information in order to create it from scratch.
+     *
      *  @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition saveFile(const OFFilename &fileName,
@@ -341,7 +325,7 @@ class DCMTK_DCMDATA_EXPORT DcmFileFormat
                                  const E_PaddingEncoding padEncoding = EPD_noChange,
                                  const Uint32 padLength = 0,
                                  const Uint32 subPadLength = 0,
-                                 const E_FileWriteMode writeMode = EWM_fileformat);
+                                 const E_FileWriteMode writeMode = EWM_createNewMeta);
 
     // methods for different pixel representations
 
