@@ -1,6 +1,6 @@
 /*
 *
-*  Copyright (C) 2017, OFFIS e.V.
+*  Copyright (C) 2017-2020, OFFIS e.V.
 *  All rights reserved.  See COPYRIGHT file for details.
 *
 *  This software and supporting documentation were developed by
@@ -114,13 +114,17 @@ public:
         /// allow DcmJsonFormat to use this class' private members
         friend class DcmJsonFormat;
 
-        /// private constructor, used by DcmJsonFormat
+        /** private constructor, used by DcmJsonFormat
+         * @param format the format
+         */
         inline Indention(DcmJsonFormat& format) : m_Format(format)
         {
 
         }
 
-        /// prints the current indention using the parent formatter
+        /** prints the current indention using the parent formatter
+         * @param out the stream to print to
+         */
         inline void printIndention(STD_NAMESPACE ostream& out) const
         {
             m_Format.printIndention(out);
@@ -181,14 +185,14 @@ public:
     static void printValueString(STD_NAMESPACE ostream &out,
                                  const OFString &value);
 
-    /** Print either null if empty or a Number as normelized IntegerString
+    /** Print either null if empty or a Number as normalized IntegerString
      *  @param out output stream to which the Value prefix is written
      *  @param value String that should be printed
      */
     static void printNumberInteger(STD_NAMESPACE ostream &out,
                                    OFString &value);
 
-    /** Print either null if empty or a Number as normelized IntegerDecimal
+    /** Print either null if empty or a Number as normalized IntegerDecimal
      *  @param out output stream to which the Value prefix is written
      *  @param value String that should be printed
      */
@@ -200,10 +204,15 @@ public:
      */
     inline DcmJsonFormat(const OFBool printMetaInfo)
     : printMetaheaderInformation(printMetaInfo)
+    , enableJsonExtension(OFFalse)
     {
 
     }
 
+    /** Virtual destructor, does nothing
+     */
+    virtual ~DcmJsonFormat() {}
+
     /** Method to return line break(s)
      *  @return line break(s).
      */
@@ -309,6 +318,21 @@ public:
      */
     virtual void printNextArrayElementPrefix(STD_NAMESPACE ostream &out);
 
+    /** return the flag indicating whether extended JSON number encoding is enabled.
+     */
+    virtual OFBool getJsonExtensionEnabled() const
+    {
+      return enableJsonExtension;
+    }
+
+    /** set the flag indicating whether extended JSON number encoding is enabled.
+     *  @param enabled new value of the flag
+     */
+    virtual void setJsonExtensionEnabled(OFBool enabled)
+    {
+      enableJsonExtension = enabled;
+    }
+
     /** Option that defines if metaheader information should be printed.
      */
     const OFBool printMetaheaderInformation;
@@ -326,6 +350,16 @@ protected:
     /** Used for decreasing the indention level.
      */
     virtual void decreaseIndention() = 0;
+
+private:
+
+    /** Option that defines if the inofficial JSON extension should be
+     *  permitted under which decimal numbers may have the values "-inf",
+     *  "inf" or "nan". Default is OFFalse, in which case such values
+     *  will lead to an error code being returned instead.
+     */
+    OFBool enableJsonExtension;
+
 };
 
 
@@ -335,7 +369,7 @@ protected:
 class DCMTK_DCMDATA_EXPORT DcmJsonFormatPretty : public DcmJsonFormat
 {
 private:
-    /** Variable for the indentenlevel of DcmJsonFormat
+    /** Variable for the indention level of DcmJsonFormat
      */
     unsigned m_IndentionLevel;
 
