@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2020, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -409,19 +409,52 @@ class DCMTK_DCMDATA_EXPORT DcmObject
      *  @param vr value representation
      *  @return EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition setVR(DcmEVR /*vr*/) { return EC_IllegalCall; }
+#ifdef DOXYGEN
+    virtual OFCondition setVR(DcmEVR vr)
+#else
+    virtual OFCondition setVR(DcmEVR /* vr */)
+#endif
+    {
+      return EC_IllegalCall;
+    }
 
-    /** return value multiplicity of the current object
-     *  @return value multiplicity of the current object
+    /** get value multiplicity of this object.
+     *  Please note that depending on the Value Representation (VR), subclasses
+     *  derived from this class either return the number of currently stored
+     *  values or the constant value 1 (as defined in the DICOM standard).
+     *  See getNumberOfValues(), which always returns the number of stored values.
+     *  @return value multiplicity of this object
      */
     virtual unsigned long getVM() = 0;
 
+    /** get number of values stored in this object
+     *  @return number of values in this object
+     */
+    virtual unsigned long getNumberOfValues() = 0;
+
     /** calculate the length of this DICOM element when encoded with the
      *  given transfer syntax and the given encoding type for sequences.
      *  For elements, the length includes the length of the tag, length field,
      *  VR field and the value itself, for items and sequences it returns
      *  the length of the complete item or sequence including delimitation tags
-     *  if applicable. Never returns undefined length.
+     *  if applicable.
+     *  @warning Since calcElementLength() returns a 32 bit integer, an
+     *    overflow during calculation is possible for some derived classes that
+     *    actually represent a compound value (e.g. items like DcmPixelItem).
+     *    Such overflows will be detected, in which case the maximum possible
+     *    value will be returned instead, coinciding with DCM_UndefinedLength.
+     *  @warning The implementation in DcmPixelData may return zero if no
+     *    conforming representation exists and set the
+     *    EC_RepresentationNotFound error flag to indicated it.
+     *  @warning When calculation the length of a sequence or an item
+     *    containing multiple attributes, the implementation may return
+     *    DCM_UndefinedLength to indicate a value that can not be encoded as
+     *    a 32 bit length field. It will even do so if
+     *    "dcmWriteOversizedSeqsAndItemsUndefined" is disabled, but then also
+     *    set the EC_SeqOrItemContentOverflow error flag (inside getLength())
+     *    to indicated it.
+     *  @note Just check for zero or DCM_UndefinedLength return value and then
+     *    have a look at the error flag in either case.
      *  @param xfer transfer syntax for length calculation
      *  @param enctype sequence encoding type for length calculation
      *  @return length of DICOM element
@@ -478,7 +511,7 @@ class DCMTK_DCMDATA_EXPORT DcmObject
      *  @param flags optional flag used to customize the output (see DCMTypes::XF_xxx)
      *  @return status, always returns EC_Illegal Call
      */
-    virtual OFCondition writeXML(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeXML(STD_NAMESPACE ostream &out,
                                  const size_t flags = 0);
 
     /** write object in JSON format to a stream
@@ -486,7 +519,7 @@ class DCMTK_DCMDATA_EXPORT DcmObject
      *  @param format used to format and customize the output
      *  @return status, always returns EC_Illegal Call
      */
-    virtual OFCondition writeJson(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeJson(STD_NAMESPACE ostream &out,
                                   DcmJsonFormat &format);
 
     /** special write method for creation of digital signatures (abstract)
