@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2020, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -48,7 +48,8 @@ public:
     // constructor allowing construction using an explicit value length.
     friend class DcmItem;
 
-    /** constructor
+    /** constructor.
+     *  Create new element from given tag.
      *  @param tag attribute tag
      */
     DcmSequenceOfItems(const DcmTag &tag);
@@ -137,7 +138,7 @@ public:
      *  @param pixelFileName not used (used in certain sub-classes of this class)
      *  @param pixelCounter not used (used in certain sub-classes of this class)
      */
-    virtual void print(STD_NAMESPACE ostream&out,
+    virtual void print(STD_NAMESPACE ostream &out,
                        const size_t flags = 0,
                        const int level = 0,
                        const char *pixelFileName = NULL,
@@ -156,7 +157,18 @@ public:
     /** get value multiplicity
      *  @return always returns 1 (according to the DICOM standard)
      */
-    virtual unsigned long getVM() { return 1L; }
+    virtual unsigned long getVM();
+
+    /** get number of values (items) stored in this sequence.
+     *  The result is the same as card() unless overwritten in a derived class.
+     *  @return number of items in this sequence
+     */
+    virtual unsigned long getNumberOfValues();
+
+    /** get cardinality of this sequence
+     *  @return number of items in this sequence
+     */
+    virtual unsigned long card() const;
 
     /** This function takes care of group length and padding elements
      *  in the current element list according to what is specified in
@@ -195,21 +207,7 @@ public:
                              const Uint32 subPadlen = 0,
                              Uint32 instanceLength = 0);
 
-    /** calculate the length of this DICOM element when encoded with the
-     *  given transfer syntax and the given encoding type for sequences.
-     *  For elements, the length includes the length of the tag, length field,
-     *  VR field and the value itself, for items and sequences it returns
-     *  the length of the complete item or sequence including delimitation tags
-     *  if applicable.
-     *  If length encoding is set to be explicit and the total sequence size is
-     *  larger than the available 32-bit length field, then undefined length
-     *  is returned. If "dcmWriteOversizedSeqsAndItemsUndefined" is disabled,
-     *  also the internal DcmObject errorFlag is set to EC_SeqOrItemContentOverflow
-     *  in case the sequence content (excluding tag header etc.) is already too
-     *  large.
-     *  @param xfer transfer syntax for length calculation
-     *  @param enctype sequence encoding type for length calculation
-     *  @return length of DICOM element
+    /** @copydoc DcmObject::calcElementLength()
      */
     virtual Uint32 calcElementLength(const E_TransferSyntax xfer,
                                      const E_EncodingType enctype);
@@ -282,7 +280,7 @@ public:
      *  @param flags optional flag used to customize the output (see DCMTypes::XF_xxx)
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition writeXML(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeXML(STD_NAMESPACE ostream &out,
                                  const size_t flags = 0);
 
     /** write object in JSON format
@@ -290,7 +288,7 @@ public:
      *  @param format used to format and customize the output
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition writeJson(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeJson(STD_NAMESPACE ostream &out,
                                   DcmJsonFormat &format);
 
     /** special write method for creation of digital signatures
@@ -343,11 +341,6 @@ public:
      */
     virtual OFCondition convertCharacterSet(DcmSpecificCharacterSet &converter);
 
-    /** get cardinality of this sequence
-     *  @return number of items in this sequence
-     */
-    virtual unsigned long card() const;
-
     /** insert the given item at the start of the item list maintained by this sequence.
      *  Ownership of the item, which must be allocated on the heap, is transferred to the sequence.
      *  @param item pointer to DcmItem instance allocated on the heap, must not be NULL.
