@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -170,7 +170,7 @@ class DCMTK_DCMDATA_EXPORT DcmTime
     // ensure inherited overloads of matches take part in overload resolution
     using DcmByteString::matches;
 
-    /// @copydoc DcmByteString::matches(OFString,OFString,OFBool)
+    /// @copydoc DcmByteString::matches(const OFString&,const OFString&,const OFBool) const
     virtual OFBool matches(const OFString& key,
                            const OFString& candidate,
                            const OFBool enableWildCardMatching = OFTrue) const;
@@ -372,6 +372,26 @@ class DCMTK_DCMDATA_EXPORT DcmTime
                                              const size_t dicomTimeZoneSize,
                                              double &timeZone);
 
+    /** check whether given string conforms to a single value of VR "TM" (Time).
+     *  The old ACR/NEMA time format is considered invalid.
+     *  @param dicomTime string value to be checked
+     *  @param dicomTimeSize the size (in bytes) of the string 'dicomTime' refers to
+     *  @return OFTrue if the given string conforms to the Time format, OFFalse otherwise
+     */
+    static OFBool check(const char* dicomTime, const size_t dicomTimeSize);
+
+    /** check whether given string conforms to a single value of VR "TM" (Time).
+     *  @param dicomTime string value to be checked
+     *  @param dicomTimeSize the size (in bytes) of the string 'dicomTime' refers to
+     *  @param supportOldFormat whether to accept the old ACR/NEMA time format.
+     *    Set to OFTrue for enabling support for (HH:MM:SS in addition to HHMMSS...).
+     *    Defaults to OFFalse, disabling it by default.
+     *  @return OFTrue if the given string conforms to the Time format, OFFalse otherwise
+     */
+    static OFBool check(const char* dicomTime, /* STOP: DICOM time!! */
+                        const size_t dicomTimeSize,
+                        const OFBool supportOldFormat);
+
     /** check whether given string value conforms to the VR "TM" (Time)
      *  and to the specified VM.
      *  @param value string value to be checked (possibly multi-valued)
