@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2017, OFFIS e.V.
+ *  Copyright (C) 2000-2021, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -34,6 +34,7 @@
 
 #include "dcmtk/dcmdata/dcvrcs.h"
 #include "dcmtk/dcmdata/dcvrda.h"
+#include "dcmtk/dcmdata/dcvrds.h"
 #include "dcmtk/dcmdata/dcvris.h"
 #include "dcmtk/dcmdata/dcvrlo.h"
 #include "dcmtk/dcmdata/dcvrpn.h"
@@ -139,10 +140,10 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition readPatientData(DcmItem &dataset,
                                         const size_t flags = 0);
 
-    /** read study data from DICOM dataset. Also reads patient data.
-     *  The list of data elements that are read can be found under "Patient Module" and
-     *  "General Study Module" in the member variable section of this class.  Other data
-     *  is not changed, so be careful when using this method.
+    /** read study data from DICOM dataset.  Also reads patient data.
+     *  The list of data elements that are read can be found under "Patient Module", "General
+     *  Study Module" and "Patient Study Module" in the member variable section of this class.
+     *  Other data is not changed, so be careful when using this method.
      *  @param  dataset  reference to DICOM dataset from which the data should be read
      *  @param  flags    optional flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -263,7 +264,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSpecificCharacterSetType(const E_CharacterSet characterSet);
 
     /** get document preliminary flag.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return preliminary flag (might be DSRTypes::PF_invalid if not specified)
      */
     virtual E_PreliminaryFlag getPreliminaryFlag() const;
@@ -271,7 +272,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** set document preliminary flag.
      *  According to the DICOM standard, the concept of "completeness" is independent of the
      *  concept of "preliminary" or "final".  Therefore, this flag can be specified separately.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  flag  preliminary flag to be set (use DSRTypes::PF_invalid to omit this optional
      *                value)
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -281,19 +282,19 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get document completion flag.
      *  According to the DICOM standard, this flag describes the estimated degree of completeness
      *  of an SR Document.  See DICOM standard for details.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return completion flag (might be DSRTypes::CF_invalid if read from dataset)
      */
     virtual E_CompletionFlag getCompletionFlag() const;
 
     /** get document verification flag.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return verification flag (might be DSRTypes::VF_invalid if read from dataset)
      */
     virtual E_VerificationFlag getVerificationFlag() const;
 
     /** check whether there are one or more verifying observers.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return OFTrue if there is at least one verifying observer, OFFalse otherwise
      */
     virtual OFBool hasVerifyingObservers() const;
@@ -302,7 +303,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  A document can be verified more than once.  The verification flag should be VERIFIED
      *  if any verifying observer is specified.  The details on the observer can be retrieved
      *  using the getVerifyingObserver() methods.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return number of verifying observers (if any), 0 otherwise
      */
     virtual size_t getNumberOfVerifyingObservers() const;
@@ -310,7 +311,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get information about a verifying observer.
      *  All reference variables are cleared before the information is retrieved, i.e. if an error
      *  occurs (return value != EC_Normal) non-empty variables do contain valid (empty) data.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  idx           index of the verifying observer to be retrieved (starting with 1).
      *                        Use getNumberOfVerifyingObservers() to get the maximum value.
      *  @param  dateTime      reference to variable where the date and time when this document
@@ -329,7 +330,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get information about a verifying observer.
      *  All reference variables are cleared before the information is retrieved, i.e. if an error
      *  occurs (return value != EC_Normal) non-empty variables do contain valid (empty) data.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  idx           index of the verifying observer to be retrieved (starting with 1).
      *                        Use getNumberOfVerifyingObservers() to get the maximum value.
      *  @param  dateTime      reference to variable where the date and time when this document
@@ -357,7 +358,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  included in this document with or without modification." and "[...] the use of the
      *  Predecessor Document Sequence allows tracing back to the input SR Document, which in this
      *  case is the previous version."
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return reference to list object
      */
     virtual DSRSOPInstanceReferenceList &getPredecessorDocuments();
@@ -398,7 +399,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  reference all other evidence considered pertinent for this SR Document that is not listed
      *  in the Current Requested Procedure Evidence Sequence.  This requires that the same SOP
      *  Instance shall not be referenced in both of these Sequences."
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return reference to list object
      */
     virtual DSRSOPInstanceReferenceList &getPertinentOtherEvidence();
@@ -411,7 +412,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Group 7006 (SR Document Purposes of Reference).
      *  Note: An equivalent rendering of the document might be provided as an "Encapsulated PDF"
      *  DICOM object.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return reference to list object
      */
     virtual DSRReferencedInstanceList &getReferencedInstances();
@@ -435,7 +436,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
                                                 const signed long pos = 0) const;
 
     /** get completion flag description.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -523,6 +524,22 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getPatientSex(OFString &value,
                                       const signed long pos = 0) const;
 
+    /** get patient's size
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getPatientSize(OFString &value,
+                                       const signed long pos = 0) const;
+
+    /** get patient's weight
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getPatientWeight(OFString &value,
+                                         const signed long pos = 0) const;
+
     /** get referring physician's name
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -579,7 +596,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getDeviceSerialNumber(OFString &value,
                                               const signed long pos = 0) const;
 
-    /** get software version(s). Please note that only the first component is returned.
+    /** get software version(s)
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -587,6 +604,30 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getSoftwareVersions(OFString &value,
                                             const signed long pos = 0) const;
 
+    /** get synchronization frame of reference UID
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getSynchronizationFrameOfReferenceUID(OFString &value,
+                                                              const signed long pos = 0) const;
+
+    /** get synchronization trigger
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getSynchronizationTrigger(OFString &value,
+                                                  const signed long pos = 0) const;
+
+    /** get acquisition time synchronized
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getAcquisitionTimeSynchronized(OFString &value,
+                                                       const signed long pos = 0) const;
+
     /** get study date
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -667,6 +708,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getPatientID(OFString &value,
                                      const signed long pos = 0) const;
 
+    /** get issuer of patient ID
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getIssuerOfPatientID(OFString &value,
+                                             const signed long pos = 0) const;
+
     /** get series number
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -708,7 +757,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
                                                 const OFBool check = OFTrue);
 
     /** set completion flag description.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  value  explanation of the value that is set for completion flag.  If an empty
      *                 string is passed, the description is removed from the dataset (type 3).
      *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
@@ -751,6 +800,22 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setPatientSex(const OFString &value,
                                       const OFBool check = OFTrue);
 
+    /** set patient's size
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (DS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setPatientSize(const OFString &value,
+                                       const OFBool check = OFTrue);
+
+    /** set patient's weight
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (DS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setPatientWeight(const OFString &value,
+                                         const OFBool check = OFTrue);
+
     /** set referring physician's name
      ** @param  value  value to be set (single value only) or "" for no value
      *  @param  check  check 'value' for conformance with VR (PN) and VM (1) if enabled
@@ -815,6 +880,29 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSoftwareVersions(const OFString &value,
                                             const OFBool check = OFTrue);
 
+    /** set synchronization frame of reference UID
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (UI) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setSynchronizationFrameOfReferenceUID(const OFString &value,
+                                                              const OFBool check = OFTrue);
+    /** set synchronization trigger
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setSynchronizationTrigger(const OFString &value,
+                                                  const OFBool check = OFTrue);
+
+    /** set acquisition time synchronized
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setAcquisitionTimeSynchronized(const OFString &value,
+                                                       const OFBool check = OFTrue);
+
     /** set content date
      ** @param  value  value to be set (single value only).  If an empty string is passed,
      *                 the current date is set when displaying or writing the document since
@@ -883,6 +971,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setPatientID(const OFString &value,
                                      const OFBool check = OFTrue);
 
+    /** set issuer of patient ID
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setIssuerOfPatientID(const OFString &value,
+                                             const OFBool check = OFTrue);
+
     /** set series number
      ** @param  value  value to be set (single value only).  If an empty string is passed,
      *                 the value "1" is set when displaying or writing the document since
@@ -918,7 +1014,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  After generating a new study instance UID the method createNewSeries() is called,
      *  i.e. also a new series instance UID and SOP instance UID are generated.  This is
      *  a requirement of the DICOM standard.  All other study-related attributes are
-     *  cleared.
+     *  cleared (including the attributes from the Patient Study Module).
      */
     virtual void createNewStudy();
 
@@ -998,7 +1094,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  reset (OFFalse).  The preliminary flag is not modified by this method.  Also the
      *  various lists of referenced instances remain unchanged, i.e. they have to be
      *  adapted manually if needed.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      *  @param  clearList  clear list of predecessor documents before adding the current
      *                     document if OFTrue.  Append current document to existing list
      *                     otherwise.
@@ -1011,7 +1107,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  describes the estimated degree of completeness of an SR Document (see DICOM standard
      *  for details).  The completion flag description is set to an empty string (i.e. absent
      *  in DICOM dataset).
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition completeDocument();
@@ -1021,7 +1117,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  describes the estimated degree of completeness of an SR Document (see DICOM standard
      *  for details).  The completion flag description can be modified independently from the
      *  flag by means of the method setCompletionFlagDescription() - see above.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  description  explanation of the value set for completion flag.
      *                       (optional, see previous method, VR=LO)
      *  @param  check        check 'description' for conformance with VR and VM if enabled
@@ -1037,7 +1133,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Please note that only completed documents (see completion flag) can be verified and that
      *  a new SOP instance UID has to be generated (manually) according to the DICOM standard when
      *  creating a dataset/file from this document.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  observerName  name of the person who has verified this document (required, VR=PN)
      *  @param  organization  name of the organization to which the observer belongs (required, VR=LO)
      *  @param  dateTime      verification date time (optional). If empty/absent the current date and
@@ -1058,7 +1154,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Please note that only completed documents (see completion flag) can be verified and that
      *  a new SOP instance UID has to be generated (manually) according to the DICOM standard when
      *  creating a dataset/file from this document.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to document types that use the Key Object Document Module.
      ** @param  observerName  name of the person who has verified this document (required, VR=PN)
      *  @param  observerCode  code identifying the verifying observer (optional, see previous method)
      *  @param  organization  name of the organization to which the observer belongs (required, VR=LO)
@@ -1091,9 +1187,9 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *      document management functions do reset the flag (i.e. set the FinalizedFlag to OFFalse),
      *      other methods (e.g. setXXX) do not change the flag though the state of the document is
      *      not finalized any more after they have been called.
-     *  @note Not applicable to Key Object Selection Documents since there's no completion flag in
-     *        this type of SR document.  Please note that this method has nothing to do with the
-     *        preliminary flag.
+     *  @note Not applicable to document types that use the Key Object Document Module since there
+     *        is no completion flag attribute in this module.  Please note that this method has
+     *        nothing to do with the preliminary flag.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition finalizeDocument();
@@ -1291,11 +1387,20 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmPersonName       PatientName;
     /// Patient ID: (LO, 1, 2)
     DcmLongString       PatientID;
+    /// Issuer of Patient ID: (LO, 1, 3)
+    DcmLongString       IssuerOfPatientID;
     /// Patient's Birth Date: (DA, 1, 2)
     DcmDate             PatientBirthDate;
     /// Patient's Sex: (CS, 1, 2)
     DcmCodeString       PatientSex;
 
+    // --- Patient Study Module (U) ---
+
+    /// Patient's Size: (DS, 1, 3)
+    DcmDecimalString    PatientSize;
+    /// Patient's Weight: (DS, 1, 3)
+    DcmDecimalString    PatientWeight;
+
     // --- General Equipment Module (M) ---
 
     /// Manufacturer: (LO, 1, 2)
@@ -1318,9 +1423,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     // Software Version(s): (LO, 1-n, 1)
     // - see 'General Equipment Module'
 
-    // --- Synchronization Module (C/U - for some IODs) ---
+    // --- Synchronization Module (M/C/U - for some IODs) ---
 
-    // tbd: conditional/optional module not yet supported
+    /// Synchronization Frame of Reference UID: (UI, 1, 1)
+    DcmUniqueIdentifier SynchronizationFrameOfReferenceUID;
+    /// Synchronization Trigger: (CS, 1, 1)
+    DcmCodeString       SynchronizationTrigger;
+    /// Acquisition Time Synchronized: (CS, 1, 1)
+    DcmCodeString       AcquisitionTimeSynchronized;
 
     // --- SR Document Series / Key Object Document Series Module (M) ---
 
