@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2017, OFFIS e.V.
+ *  Copyright (C) 2000-2021, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -33,12 +33,16 @@
 #include "dcmtk/ofstd/oflimits.h"   /* for OFnumeric_limits<T>::max() */
 #include "dcmtk/ofstd/oferror.h"
 
-#define INCLUDE_CASSERT
-#define INCLUDE_CSTDLIB
-#define INCLUDE_CSTDIO
-#define INCLUDE_CSTRING
-#define INCLUDE_UNISTD
-#include "dcmtk/ofstd/ofstdinc.h"
+#include <cassert>
+#include <cstdlib>
+#include <cstdio>
+#include <cstring>
+#include <cstdarg>
+#ifdef HAVE_UNISTD_H
+BEGIN_EXTERN_C
+#include <unistd.h>
+END_EXTERN_C
+#endif
 
 BEGIN_EXTERN_C
 #ifdef HAVE_SYS_TYPES_H
@@ -46,6 +50,13 @@ BEGIN_EXTERN_C
 #endif
 END_EXTERN_C
 
+/* Check if we are using glibc in a version where readdir() is known to be
+ * thread-safe and where readdir_r() is deprecated.
+ */
+#if defined(__GLIBC__) && (((__GLIBC__ == 2) && (__GLIBC_MINOR__ >= 24)) || (__GLIBC__ >= 3))
+#define READDIR_IS_THREADSAFE
+#endif
+
 /*------------------------*
  *  forward declarations  *
  *------------------------*/
@@ -136,6 +147,42 @@ class DCMTK_OFSTD_EXPORT OFStandard
 #endif
     }
 
+    /** Standard C99 formatted string output function.
+     *  This is an implementation of the snprintf(3) function as defined in the
+     *  C99 standard. Like all functions of the  printf() family, it produces
+     *  output according to a format string. Output is written to the character
+     *  array passed as parameter str. The function never writes more than size
+     *  bytes and guarantees that the result will be NUL terminated, although
+     *  it may be truncated if the buffer provided is too small.
+     *  @param str string buffer to write to
+     *  @param size size of string buffer, in bytes
+     *  @param format printf() format string
+     *  @param ... parameters to be formatted
+     *  @return number of characters that have been written (if the buffer is
+     *    large enough) or the number of characters that would have been
+     *    written (if the buffer is too small), in both cases not including
+     *    the final NUL character.
+     */
+    static int snprintf(char *str, size_t size, const char *format, ...);
+
+    /** Standard C99 formatted string output function.
+     *  This is an implementation of the snprintf(3) function as defined in the
+     *  C99 standard. Like all functions of the  printf() family, it produces
+     *  output according to a format string. Output is written to the character
+     *  array passed as parameter str. The function never writes more than size
+     *  bytes and guarantees that the result will be NUL terminated, although
+     *  it may be truncated if the buffer provided is too small.
+     *  @param str string buffer to write to
+     *  @param size size of string buffer, in bytes
+     *  @param format printf() format string
+     *  @param ap parameters to be formatted
+     *  @return number of characters that have been written (if the buffer is
+     *    large enough) or the number of characters that would have been
+     *    written (if the buffer is too small), in both cases not including
+     *    the final NUL character.
+     */
+    static int vsnprintf(char *str, size_t size, const char *format, va_list ap);
+
     /** convert a given error code to a string. This function wraps the various
      *  approaches found on different systems. Internally, the standard function
      *  strerror() or strerror_r() is used.
@@ -569,10 +616,14 @@ class DCMTK_OFSTD_EXPORT OFStandard
      *  (") is converted to "&#34;" instead of "&quot;" because the latter entity is not defined.
      *  In HTML mode, the apostrophe sign (') is converted to "&#39;" instead of "&apos;" for the
      *  same reason.
+     *  @note This method might create invalid character entity references, such as "&#27;" for ESC,
+     *    if contained in the 'sourceString'.  An XML document with such character entities cannot
+     *    be parsed by most XML parsers.  However, removing them from the output stream would also
+     *    be no option.
      ** @param out stream used for the HTML/XHTML/XML mnenonic output
      *  @param sourceString source string to be converted.  May contain one or more NULL bytes.
      *  @param convertNonASCII convert non-ASCII characters (< # 32 and >= #127) to numeric value
-     *    (@&@#nnn;) if OFTrue
+     *    (@&@#nnn;) if OFTrue.  This might lead to invalid XML character entity references.
      *  @param markupMode convert to HTML, HTML 3.2, XHTML or XML markup.
      *    LF and CR are encoded as "&#10;" and "&#13;" in XML mode, the flag 'newlineAllowed'
      *    has no meaning in this case.
@@ -598,10 +649,14 @@ class DCMTK_OFSTD_EXPORT OFStandard
      *  (") is converted to "&#34;" instead of "&quot;" because the latter entity is not defined.
      *  In HTML mode, the apostrophe sign (') is converted to "&#39;" instead of "&apos;" for the
      *  same reason.
+     *  @note This method might create invalid character entity references, such as "&#27;" for ESC,
+     *    if contained in the 'sourceString'.  An XML document with such character entities cannot
+     *    be parsed by most XML parsers.  However, removing them from the 'markupString' would also
+     *    be no option.
      ** @param sourceString source string to be converted.  May also contain one or more NULL bytes.
      *  @param markupString reference to character string where the result should be stored
      *  @param convertNonASCII convert non-ASCII characters (< # 32 and >= #127) to numeric value
-     *    (@&@#nnn;) if OFTrue
+     *    (@&@#nnn;) if OFTrue.  This might lead to invalid XML character entity references.
      *  @param markupMode convert to HTML, HTML 3.2, XHTML or XML markup string.
      *    LF and CR are encoded as "@&@#10;" and "@&@#13;" in XML mode, the flag 'newlineAllowed'
      *    has no meaning in this case.
@@ -855,13 +910,13 @@ class DCMTK_OFSTD_EXPORT OFStandard
     static OFBool
     safeSubtract(T minuend, T subtrahend, T& difference)
     {
-      assert(!OFnumeric_limits<T>::is_signed);
-      if (minuend < subtrahend) {
-        return OFFalse;
-      } else {
-        difference = minuend - subtrahend;
-        return OFTrue;
-      }
+        assert(!OFnumeric_limits<T>::is_signed);
+        if (minuend < subtrahend) {
+            return OFFalse;
+        } else {
+            difference = minuend - subtrahend;
+            return OFTrue;
+        }
     }
 
     /** check whether addition is safe (i.e.\ no overflow occurs) and if so,
@@ -877,13 +932,34 @@ class DCMTK_OFSTD_EXPORT OFStandard
     static OFBool
     safeAdd(T a, T b, T& sum)
     {
-      assert(!OFnumeric_limits<T>::is_signed);
-      if ((OFnumeric_limits<T>::max)() - a < b) {
-        return OFFalse;
-      } else {
-        sum = a + b;
+        assert(!OFnumeric_limits<T>::is_signed);
+        if ((OFnumeric_limits<T>::max)() - a < b) {
+            return OFFalse;
+        } else {
+            sum = a + b;
+            return OFTrue;
+        }
+    }
+
+    /** check whether multiplication is safe (i.e.\ no overflow occurs) and if so,
+     *  perform it (i.e.\ compute a*b=product). Only works for unsigned types.
+     *  @param a first number to multiply
+     *  @param b second number to multiply
+     *  @param product resulting product of both numbers, if multiplication is
+     *    safe, otherwise parameter value is not touched by the function
+     *  @return OFTrue if multiplication is safe and could be performed, OFFalse
+     *    otherwise
+     */
+    template <typename T>
+    static OFBool safeMult(T a, T b, T& product)
+    {
+        assert(!OFnumeric_limits<T>::is_signed);
+        T x = a * b;
+        if (a != 0 && x / a != b) {
+            return OFFalse;
+        }
+        product = x;
         return OFTrue;
-      }
     }
 
 #ifdef DOXYGEN
@@ -908,7 +984,7 @@ class DCMTK_OFSTD_EXPORT OFStandard
      *    be OFTrue.
      *  @tparam Count the number of digits to extract. Must be greater zero
      *    and less or equal to OFnumeric_limits<T>::digits10
-     *  @param string a pointer to a character array to extract digits from.
+     *  @tparam string a pointer to a character array to extract digits from.
      *  @return a value of type T that is equivalent to the number represented
      *    by the digits.
      *  @details
@@ -947,7 +1023,7 @@ class DCMTK_OFSTD_EXPORT OFStandard
     static OFTypename OFenable_if
     <
         OFnumeric_limits<T>::is_integer && ( Count > 1 ) &&
-             OFnumeric_limits<T>::digits10 >= Count,
+             OFstatic_cast(size_t, OFnumeric_limits<T>::digits10) >= Count,
         T
     >::type extractDigits(const char* string)
     {
@@ -972,6 +1048,18 @@ class DCMTK_OFSTD_EXPORT OFStandard
      */
     static void trimString( const char*& pBegin, const char*& pEnd );
 
+    /** An utility function that finds a substring within a string that does
+     *  not contain leading and trailing spaces and null bytes, effectively
+     *  trimming the string without unnecessary copies.
+     *  @param str a reference to a pointer to the beginning of the string.
+     *  @param size a reference to a size_t variable containing the number of
+     *    bytes in the string referenced by str.
+     *  @details
+     *  This overload is implemented using the other overload of the function
+     *  operating on two character pointers.
+     */
+    static void trimString( const char*& str, size_t& size );
+
     /** This function performs a reverse DNS lookup of a hostname.
      *  The parameters are identical to those passed to gethostbyaddr().
      *  If the lookup fails, an empty string is returned.
@@ -1066,6 +1154,17 @@ class DCMTK_OFSTD_EXPORT OFStandard
      */
     static OFerror_code getLastNetworkErrorCode();
 
+   /** Method that ensures that the current thread is actually sleeping for the
+    *  defined number of seconds (at least).
+    *  The problem with the regular sleep() function called from
+    *  OFStandard::sleep is that it might be interrupted by signals or a
+    *  network timeout (depending on the operating system). This methods
+    *  re-executes OFStandard's sleep method until the desired number of
+    *  seconds have elapsed.
+    *  @param seconds The number of seconds to sleep (at least)
+    */
+    static void forceSleep(Uint32 seconds);
+
  private:
 
     /** private implementation of strlcpy. Called when strlcpy
